/*
 * Project name:
       BI Hall Click
 * Copyright:
      (c) mikroElektronika, 2014.
 * Revision History:
      20140820:
      - Initial release (RD);
 * Description:
      Bi Hall click is a simple solution for adding a bipolar Hall switch to your design.
      It carries the Melexis US2882 bipolar Hall-effect switch and a 74LVC1T45 single bit, dual supply transceiver.
      Bi Hall click communicates with the target board through the mikroBUS INT line.
      The board is designed to use either a 3.3V or 5V power supply (which also defines the logic level of the output signal).
      A bipolar Hall effect sensor is sensitive to both north and south pole magnetic fields.
      Bi Hall click outputs a HIGH logic level when exposed to a South Pole magnetic field, and a LOW logic level
      when exposed to a North Pole magnetic field. When removed from a magnetic field, the logic level stays in its previous state.
      It's suitable for any application where alternating north and south poles are used to ensure switching.
      For example, to measure rotary speed by utilizing a ring magnet with north and south poles.

      - PortD count state changes.

 * Test configuration:
     MCU:             STM32F107VC
                      http://www.st.com/st-web-ui/static/active/en/resource/technical/document/reference_manual/CD00171190.pdf
     Dev. Board:      EasyMx PRO v7 for STM32
                      http://www.mikroe.com/eng/products/view/852/easymx-pro-v7-for-stm32/
     Oscillator:      HS-PLL 72.0000 MHz
     ext. modules:    BI Hall Click
                      http://www.mikroe.com/click/bi-hall/
     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/mikroc/arm/
 * NOTES:
      - Place BI Hall Click board in the mikroBUS socket 1.
      - Set development board J5 jumper according to SMD jumper on click board. By default it's soldered in the 3.3V position.
      - Turn On SW15-6 switches for PORTD LEDs.
*/

char cnt, old_cnt;

void ExtInt() iv IVT_INT_EXTI15_10 ics ICS_AUTO {
  EXTI_PR.B10 = 1;                     // clear flag
  cnt++;
}

void main() {
   GPIO_Digital_Output(&GPIOD_BASE, _GPIO_PINMASK_ALL);             // Enable digital output on PORTD
   GPIOD_ODR = 0;
   GPIO_Digital_Input(&GPIOD_BASE, _GPIO_PINMASK_10);               // Reset PortD
   cnt     = 0;
   old_cnt = cnt;

   RCC_APB2ENR.AFIOEN = 1;              // Enable clock for alternate pin functions
   AFIO_EXTICR3 = 0x0300;               // PD10 as External interrupt
   EXTI_RTSR = 0x00000400;              // Set interrupt on Rising edge
   EXTI_IMR |= 0x00000400;              // Set mask
   NVIC_IntEnable(IVT_INT_EXTI15_10);   // Enable External interrupt

   EnableInterrupts();                  // Enables the processor interrupt.

   while(1) {
      if (old_cnt != cnt) {
         GPIOD_ODR = cnt;
         old_cnt = cnt;
      }
   }
}